@@ -238,6 +238,89 @@ ggplot(my.cars, aes(wt, mpg, label = name)) +
   scale_colour_discrete(l = 40) +
   expand_limits(x = 6.5)
 
+## -----------------------------------------------------------------------------
+# With a factor mapped to x, highlight pairs
+
+my.cars <- mtcars
+my.cars$name <- rownames(my.cars)
+p1 <- ggplot(my.cars, aes(factor(cyl), mpg)) +
+       geom_boxplot(width = 0.33)
+
+## -----------------------------------------------------------------------------
+my.pairs <-
+  data.frame(A = 1:2, B = 2:3, bar.height = c(12, 30),
+             p.value = c(0.01, 0.05678))
+
+## -----------------------------------------------------------------------------
+p1 +
+  geom_text_pairwise(data = my.pairs,
+                     aes(xmin = A, xmax = B,
+                         y = bar.height,
+                         label = p.value),
+                     parse = TRUE)
+
+
+## -----------------------------------------------------------------------------
+p1 +
+  geom_label_pairwise(data = my.pairs,
+                      aes(xmin = A, xmax = B,
+                          y = bar.height,
+                          label = sprintf("italic(P)~`=`~%.2f", p.value)),
+                      colour = "red", size = 2.75,
+                      arrow = grid::arrow(angle = 30,
+                                          length = unit(1.5, "mm"),
+                                          ends = "both"),
+                      parse = TRUE)
+
+## -----------------------------------------------------------------------------
+p1 +
+  geom_text_pairwise(data = my.pairs,
+                     aes(xmin = A, xmax = B,
+                         y = bar.height,
+                         label = sprintf("italic(P)~`=`~%.2f", p.value)),
+                     colour = "red", colour.target = "segment",
+                     arrow = grid::arrow(angle = 90,
+                                         length = unit(1, "mm"),
+                                         ends = "both"),
+                     parse = TRUE)
+
+## -----------------------------------------------------------------------------
+p1 +
+  geom_text_pairwise(data = my.pairs,
+                     aes(xmin = A, xmax = B,
+                         y = bar.height,
+                         label = sprintf("italic(P)~`=`~%.2f", p.value)),
+                     colour = "red", colour.target = "text",
+                     arrow = grid::arrow(angle = 90,
+                                         length = unit(1, "mm"),
+                                         ends = "both"),
+                     parse = TRUE)
+
+## -----------------------------------------------------------------------------
+# with a numeric vector mapped to x, indicate range
+
+p2 <-
+  ggplot(my.cars, aes(disp, mpg)) +
+    geom_point()
+
+my.ranges <-
+  data.frame(A = c(50, 400),
+             B = c(200, 500),
+             bar.height = 5,
+             text = c("small", "large"))
+
+## -----------------------------------------------------------------------------
+p2 +
+  geom_text_pairwise(data = my.ranges,
+                     aes(xmin = A, xmax = B,
+                     y = bar.height, label = text))
+
+## -----------------------------------------------------------------------------
+p2 +
+  geom_label_pairwise(data = my.ranges,
+                      aes(xmin = A, xmax = B,
+                          y = bar.height, label = text))
+
 ## ----eval=eval_magick---------------------------------------------------------
 file.name <- 
   system.file("extdata", "Robinin.png", 
@@ -305,10 +388,10 @@ ggplot(mpg, aes(displ, hwy, colour = factor(cyl))) +
   geom_point(alpha = 0.33) +
   stat_centroid(shape = "cross", size = 4)
 
-## ----eval = FALSE-------------------------------------------------------------
-#  ggplot(mpg, aes(displ, hwy, colour = factor(cyl))) +
-#    geom_point(alpha = 0.33) +
-#    stat_centroid(shape = "cross", size = 4, .fun = median)
+## -----------------------------------------------------------------------------
+ggplot(mpg, aes(displ, hwy, colour = factor(cyl))) +
+  geom_point(alpha = 0.33) +
+  stat_centroid(shape = "cross", size = 4, .fun = median)
 
 ## -----------------------------------------------------------------------------
 ggplot(mpg, aes(displ, hwy, colour = factor(cyl))) +
@@ -389,6 +472,7 @@ ggplot(my.data, aes(x, y)) +
 ggplot(my.data, aes(x, y)) +
   geom_quadrant_lines(colour = "red") +
   stat_quadrant_counts(colour = "red", quadrants = c(1:4)) +
+  scale_y_continuous(expand = expansion(mult = 0.12)) + # add space
   geom_point()
 
 ## -----------------------------------------------------------------------------
@@ -512,19 +596,19 @@ ggplot(data = d, aes(x, y, label = lab, colour = group)) +
                      vjust = "outward", hjust = "outward") +
   scale_x_continuous(expand = expansion(c(0.1, 0.1)))
 
-## ----eval = FALSE-------------------------------------------------------------
-#  random_string <- function(len = 6) {
-#  paste(sample(letters, len, replace = TRUE), collapse = "")
-#  }
-#  
-#  # Make random data.
-#  set.seed(1001)
-#  d <- tibble::tibble(
-#    x = rnorm(100),
-#    y = rnorm(100),
-#    group = rep(c("A", "B"), c(50, 50)),
-#    lab = replicate(100, { random_string() })
-#  )
+## -----------------------------------------------------------------------------
+random_string <- function(len = 6) {
+paste(sample(letters, len, replace = TRUE), collapse = "")
+}
+
+# Make random data.
+set.seed(1001)
+d <- tibble::tibble(
+  x = rnorm(100),
+  y = rnorm(100),
+  group = rep(c("A", "B"), c(50, 50)),
+  lab = replicate(100, { random_string() })
+)
 
 ## -----------------------------------------------------------------------------
 ggplot(data = d, aes(x, y)) +
@@ -841,6 +925,7 @@ ggplot(data = make_data_tbl(300, rfun = rgamma, shape = 2),
   stat_dens2d_filter(colour = "red", keep.fraction = 1/3)
 
 ## -----------------------------------------------------------------------------
+print(austres)
 class(austres)
 austres.df <- try_tibble(austres)
 class(austres.df)
@@ -857,11 +942,11 @@ class(lynx.df)
 head(lynx.df, 3)
 
 ## -----------------------------------------------------------------------------
-lynx.df <- try_tibble(lynx, "year")
+lynx.df <- try_tibble(lynx, time.resolution = NULL)
 head(lynx.df, 3)
 
 ## -----------------------------------------------------------------------------
-lynx_n.df <- try_tibble(lynx, "year", as.numeric = TRUE)
+lynx_n.df <- try_tibble(lynx, time.resolution = "year", as.numeric = TRUE)
 lapply(lynx_n.df, "class")
 head(lynx_n.df, 3)
 
